pub trait Fill {
// Required method
fn fill(&self, slot: Slot<'_, '_>) -> Result<(), Error>;
}Expand description
A type that requires extra work to convert into a ValueBag.
This trait is an advanced initialization API. It’s intended for erased values coming from other logging frameworks that may need to perform extra work to determine the concrete type to use.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".